Fuzzing — raider 0.2.0a0 documentation

# Fuzzing

class Fuzz(flow, fuzzing_point, fuzzing_function, flags=0)

  Fuzz an input.

  attack_authentication(authentication, user, config)

    Attacks a Flow defined in `_authentication`.

    Unlike `attack_function`, this will take into account the finite state machine defined in the hyfiles. This should be used when the authentication process can be altered by the fuzzing, for example if some token needs to be extracted again from a previous authentication step for fuzzing to work.

    It will first follow the authentication process until reaching the desired state, then it will try fuzzing it, and if a `NextStage` operation is encountered, it will follow the instruction and move to this stage, then continue fuzzing.

    Parameters

      - authentication (`Authentication`) – An `Authentication` object with the finite state machine definitions.

      - user (`User`) – A `User` object with the user specific information.

      - config (`Config`) – A `Config` object with global Raider configuration.

    Return type

      `None`

  attack_function(user, config)

    Attacks a flow defined in `_functions`.

    Fuzz blindly the Flow object. It doesn’t take into account the authentication process, so this function is useful for fuzzing stuff as an already authenticated user.

    Parameters

      - user (`User`) – A `User` object with the user specific information.

      - config (`Config`) – A `Config` object with global Raider configuration.

    Return type

      `None`

  get_fuzzing_input(flow)

    Returns the Plugin associated with the fuzzing input.

    Parameters

      flow (`Flow`) – The flow object with the plugin to be returned.

    Return type

      `Plugin`

    Returns

      The plugin object to be fuzzed.

  property is_authentication: bool

    Returns True if the IS_AUTHENTICATION flag is set.

    Return type

      `bool`